@@ -7,9 +7,9 @@
 # (It may become useful if the test is moved to ./t subdirectory.)
 
 BEGIN { $| = 1; print "1..1\n"; }
-END {print "not ok 1\n" unless $loaded;}
-require 'euhc.pl';
-$loaded = 1;
+
+use UHC;
+
 print "ok 1\n";
 
 ######################### End of black magic.
